.. _roadmap:

=========
 Roadmap
=========

Present
=======

Total Open Station is at version |version|, which is an **alpha**
release. We think it works quite well, but the number of supported
formats is still too small for a beta release.

Near Future
===========

The next version of Total Open Station will be released in 2012. See
what features are being `worked on
<https://bitbucket.org/steko/totalopenstation/issues?milestone=0.4>`_.

Future
======

Our plans for Total Open Station are focused on different areas of
user experience and development practices. We envisage future versions
based on concepts like:

- seamless integration with geospatial data software
- dedicated layout for intensive survey use
- enhanced mobile experience
- supporting always more devices and formats

If you have an incredible idea on how Total Open Station should look
like, let us know!
